stan <-
structure(list(time = c(15, 3, 46, 623, 126, 64, 1350, 23, 279, 
1024, 10, 39, 730, 1961, 136, 1, 836, 60, 3695, 1996, 0, 47, 
54, 51, 2878, 3410, 44, 994, 51, 1478, 254, 897, 148, 51, 323, 
3021, 66, 2984, 2723, 550, 66, 65, 227, 2805, 25, 631, 2734, 
12, 63, 2474, 1384, 544, 29, 48, 297, 1318, 1352, 50, 547, 431, 
68, 26, 161, 14, 2313, 1634, 146, 48, 2127, 263, 2106, 293, 2025, 
2006, 2000, 1995, 1945, 65, 731, 1866, 538, 1846, 68, 1778, 1722, 
928, 1718, 22, 40, 7, 1638, 1612, 25, 1534, 1547, 1271, 44, 1247, 
1232, 191, 1393, 1202, 1378, 1373, 274, 31, 1341, 42, 381, 1264, 
1262, 1261, 47, 1193, 626, 48, 1150, 45, 1116, 1107, 1102, 195, 
30, 1040, 993, 950, 729, 121, 202, 841, 834, 265, 1, 793, 328, 
781, 752, 738, 86, 132, 663, 660, 221, 90, 619, 618, 576, 563, 
36, 549, 548, 541, 534, 169, 122, 382, 468, 464, 10, 5, 136, 
406, 391, 374, 50, 139, 322, 292, 278, 22, 231, 145, 188, 176, 
138, 149, 119, 107, 98, 89, 60, 56, 2, 1), status = c(1, 1, 1, 
1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 
1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 0, 1, 1, 1, 1, 1, 0, 1, 
1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 
1, 1, 1, 1, 0, 1, 0, 0, 0, 0, 0, 1, 1, 0, 1, 0, 1, 0, 0, 1, 0, 
1, 1, 1, 0, 0, 1, 1, 0, 1, 1, 1, 1, 1, 0, 1, 0, 0, 1, 1, 0, 1, 
1, 0, 0, 0, 1, 0, 1, 1, 1, 1, 0, 0, 0, 1, 1, 0, 0, 0, 1, 1, 1, 
0, 0, 1, 1, 0, 1, 0, 0, 0, 1, 1, 0, 0, 1, 1, 0, 0, 0, 0, 1, 0, 
0, 0, 0, 1, 1, 1, 0, 0, 1, 1, 1, 0, 0, 0, 1, 1, 0, 0, 0, 1, 0, 
1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0), age = c(54, 40, 42, 51, 
48, 54, 54, 56, 49, 43, 56, 42, 58, 33, 52, 54, 44, 64, 40, 49, 
41, 62, 49, 50, 49, 45, 36, 48, 47, 36, 48, 46, 47, 52, 48, 38, 
49, 32, 32, 48, 51, 45, 19, 48, 53, 26, 47, 29, 56, 52, 46, 52, 
53, 53, 42, 48, 54, 46, 49, 47, 51, 52, 43, 40, 26, 23, 45, 28, 
35, 49, 40, 43, 30, 15, 45, 47, 38, 55, 38, 49, 49, 44, 35, 27, 
40, 50, 39, 27, 42, 28, 48, 51, 52, 44, 50, 32, 46, 41, 18, 42, 
46, 38, 41, 41, 31, 33, 50, 19, 45, 52, 34, 47, 36, 24, 53, 51, 
32, 48, 14, 18, 39, 39, 34, 43, 30, 46, 49, 45, 48, 48, 49, 49, 
21, 19, 34, 20, 43, 41, 12, 46, 36, 42, 35, 38, 47, 50, 53, 41, 
45, 40, 30, 47, 20, 51, 51, 36, 24, 38, 13, 20, 55, 39, 27, 47, 
50, 51, 36, 43, 41, 45, 52, 50, 52, 29, 41, 21, 20, 46, 19, 27, 
13, 27, 39, 27), futime = c(3.87298334620742, 1.73205080756888, 
6.78232998312527, 24.9599679486974, 11.2249721603218, 8, 36.7423461417477, 
4.79583152331272, 16.7032930884901, 32, 3.16227766016838, 6.2449979983984, 
27.0185121722126, 44.2831796509691, 11.6619037896906, 1, 28.9136645896019, 
7.74596669241483, 60.7865116617165, 44.6766158073774, 0, 6.85565460040104, 
7.34846922834953, 7.14142842854285, 53.6469943240066, 58.3952052826257, 
6.6332495807108, 31.5277655408689, 7.14142842854285, 38.4447655734822, 
15.9373774505092, 29.9499582637439, 12.1655250605964, 7.14142842854285, 
17.9722007556114, 54.9636243346452, 8.12403840463596, 54.6260011349907, 
52.182372502599, 23.4520787991171, 8.12403840463596, 8.06225774829855, 
15.0665191733194, 52.9622507074614, 5, 25.1197133741609, 52.2876658496055, 
3.46410161513775, 7.93725393319377, 49.7393204617835, 37.2021504754766, 
23.3238075793812, 5.3851648071345, 6.92820323027551, 17.2336879396141, 
36.3042697213427, 36.7695526217005, 7.07106781186548, 23.388031127053, 
20.7605394920267, 8.24621125123532, 5.09901951359278, 12.6885775404495, 
3.74165738677394, 48.0936586256442, 40.4227658628155, 12.0830459735946, 
6.92820323027551, 46.1194102304008, 16.2172747402269, 45.8911756223351, 
17.1172427686237, 45, 44.7883913531174, 44.7213595499958, 44.6654228682546, 
44.1021541423999, 8.06225774829855, 27.0370116691915, 43.1972221329104, 
23.1948270094864, 42.9651021178817, 8.24621125123532, 42.166337284616, 
41.4969878424929, 30.4630924234556, 41.4487635521254, 4.69041575982343, 
6.32455532033676, 2.64575131106459, 40.4722126896961, 40.1497197997695, 
5, 39.1663120551323, 39.3319208785943, 35.6510869399518, 6.6332495807108, 
35.3128871660192, 35.0998575495685, 13.8202749610853, 37.322915213043, 
34.6698716467194, 37.1214223865412, 37.0540146272978, 16.5529453572468, 
5.56776436283002, 36.6196668472011, 6.48074069840786, 19.5192212959431, 
35.5527776692624, 35.5246393366632, 35.5105618091294, 6.85565460040104, 
34.5398320783411, 25.0199920063936, 6.92820323027551, 33.9116499156263, 
6.70820393249937, 33.4065861769801, 33.2716095192282, 33.1963853453957, 
13.9642400437689, 5.47722557505166, 32.2490309931942, 31.5119025131775, 
30.8220700148449, 27, 11, 14.2126704035519, 29, 28.8790581563873, 
16.2788205960997, 1, 28.1602556806574, 18.1107702762748, 27.9463772249642, 
27.4226184016042, 27.1661554144122, 9.2736184954957, 11.4891252930761, 
25.7487863791675, 25.6904651573303, 14.8660687473185, 9.48683298050514, 
24.8797106092495, 24.8596057893121, 24, 23.7276210354093, 6, 
23.43074902772, 23.4093998214393, 23.259406699226, 23.1084400165827, 
13, 11.0453610171873, 19.5448202856921, 21.6333076527839, 21.540659228538, 
3.16227766016838, 2.23606797749979, 11.6619037896906, 20.1494416796099, 
19.7737199332852, 19.3390796058137, 7.07106781186548, 11.7898261225516, 
17.9443584449264, 17.0880074906351, 16.6733320005331, 4.69041575982343, 
15.1986841535707, 12.0415945787923, 13.7113092008021, 13.2664991614216, 
11.7473401244707, 12.2065556157337, 10.9087121146357, 10.3440804327886, 
9.89949493661167, 9.4339811320566, 7.74596669241483, 7.48331477354788, 
1.4142135623731, 1)), .Names = c("time", "status", "age", "futime"
), row.names = c(NA, 184L), class = "data.frame")
